Learn R Programming

bodsr (version 0.1.0)

noc_lookup: Lookup between operator names and national operator code ('NOC') lookup

Description

Lookup between operator names and national operator code ('NOC') lookup

Usage

noc_lookup()

Arguments

Value

Returns a data frame of operator names and their corresponding national operator code from the 'BODS' API.

Examples

Run this code

##Check operator name lookup
if (FALSE) {
noc_lookup()
}

Run the code above in your browser using DataLab