Learn R Programming

bodsr (version 0.1.0)

xml_file_counter: Count the number of xml files included within a provided metadata dataframe, whether the provided file links are xml or zip

Description

Count the number of xml files included within a provided metadata dataframe, whether the provided file links are xml or zip

Usage

xml_file_counter(timetable_metadata)

Value

returns a numeric vector of number of xml files by row of the provided metadata

Arguments

timetable_metadata

A table of metadata extracted using get_timetable_metadata()