powered by
Lookup between operator names and national operator code ('NOC') lookup
noc_lookup()
Returns a data frame of operator names and their corresponding national operator code from the 'BODS' API.
##Check operator name lookup if (FALSE) { noc_lookup() }
Run the code above in your browser using DataLab